@@ -1,5 +1,7 @@
 from .blood_pressure import DiastolicPressureField, SystolicPressureField
+from .heart_rate import HeartRateField
 from .height import HeightField
+from .respiratory_rate import RespiratoryRateField
 from .temperature import TemperatureField
 from .waist_circumference import WaistCircumferenceField
 from .weight import WeightField
