@@ -6,13 +6,29 @@ from edc_vitals.model_mixins import (
     SimpleBloodPressureModelMixin,
     WeightHeightBmiModelMixin,
 )
-from edc_vitals.models.fields import TemperatureField
+from edc_vitals.models import HeartRateField, RespiratoryRateField, TemperatureField
 
 
 class BloodPressure(BloodPressureModelMixin, models.Model):
     pass
 
 
+class HeartRate(models.Model):
+
+    heart_rate = HeartRateField(
+        null=True,
+        blank=True,
+    )
+
+
+class RespiratoryRate(models.Model):
+
+    respiratory_rate = RespiratoryRateField(
+        null=True,
+        blank=True,
+    )
+
+
 class SimpleBloodPressure(SimpleBloodPressureModelMixin, models.Model):
     pass
 
